diff src/font-mgr.c @ 4328:dfd878799ef0

Autoconfiscate the recent fontconfig spelling change. ChangeLog addition: 2007-12-12 Aidan Kehoe <kehoea@parhasard.net> * configure.ac : Check for FcConfigGetRescanInterval, FcConfigSetRescanInterval. * configure : Rebuild. src/ChangeLog additon: 2007-12-12 Aidan Kehoe <kehoea@parhasard.net> * config.h.in: Make the results of the checks for FcConfigGetRescanInterval, FcConfigSetRescanInterval available. * font-mgr.h: If FcConfigSetRescanInterval and FcConfigGetRescanInterval are not available as functions, #define them to map to their old misspelled names. * font-mgr.c (Ffc_config_get_rescan_interval): * font-mgr.c (Ffc_config_set_rescan_interval): Use the correct spelling in FcConfigGetRescanInterval, FcConfigSetRescanInterval
author Aidan Kehoe <kehoea@parhasard.net>
date Fri, 14 Dec 2007 14:25:04 +0100
parents f56fa2f5f055
children a23ac8f90a49
line wrap: on
line diff
--- a/src/font-mgr.c	Fri Dec 14 14:13:02 2007 +0100
+++ b/src/font-mgr.c	Fri Dec 14 14:25:04 2007 +0100
@@ -898,10 +898,8 @@
 		intern ("fc-config-get-blanks"));
 }
 
-/* The misspelling in the fontconfig function name accurately corresponds to
-   the version of fontconfig.h I had on 2007-04-13. -- sjt */
 DEFUN("fc-config-get-rescan-interval", Ffc_config_get_rescan_interval, 1, 1, 0, /*
  -- Function: int FcConfigGetRescanInverval (FcConfig *config)
      Returns the interval between automatic checks of the configuration
      (in seconds) specified in 'config'.  The configuration is checked
      during a call to FcFontList when this interval has passed since
@@ -909,13 +907,11 @@
       (config))
 {
   CHECK_FCCONFIG (config);
-  return make_int (FcConfigGetRescanInverval (XFCCONFIG_PTR (config)));
+  return make_int (FcConfigGetRescanInterval (XFCCONFIG_PTR (config)));
 }
 
-/* The misspelling in the fontconfig function name accurately corresponds to
-   the version of fontconfig.h I had on 2007-04-13. -- sjt */
 DEFUN("fc-config-set-rescan-interval", Ffc_config_set_rescan_interval, 2, 2, 0, /*
  -- Function: FcBool FcConfigSetRescanInverval (FcConfig *config, int
           rescanInterval)
      Sets the rescan interval; returns FcFalse if an error occurred.
      XEmacs: signal such error, or return nil on success. */
@@ -923,7 +919,7 @@
 {
   CHECK_FCCONFIG (config);
   CHECK_INT (rescan_interval);
-  if (FcConfigSetRescanInverval (XFCCONFIG_PTR (config),
+  if (FcConfigSetRescanInterval (XFCCONFIG_PTR (config),
 				 XINT (rescan_interval)) == FcFalse)
     signal_error (Qio_error, "FcConfigSetRescanInverval barfed",
 		  intern ("fc-config-set-rescan-interval"));
@@ -898,10 +898,8 @@
 DEFUN("fc-config-get-rescan-interval", Ffc_config_get_rescan_interval, 1, 1, 0, /*
- -- Function: int FcConfigGetRescanInverval (FcConfig *config)
+ -- Function: int FcConfigGetRescanInterval (FcConfig *config)
      Returns the interval between automatic checks of the configuration
      (in seconds) specified in 'config'.  The configuration is checked
@@ -909,13 +907,11 @@
 DEFUN("fc-config-set-rescan-interval", Ffc_config_set_rescan_interval, 2, 2, 0, /*
- -- Function: FcBool FcConfigSetRescanInverval (FcConfig *config, int
+ -- Function: FcBool FcConfigSetRescanInterval (FcConfig *config, int
           rescanInterval)
      Sets the rescan interval; returns FcFalse if an error occurred.